@@ -11,7 +11,7 @@ isim = ipmisimdaemon.IPMISimDaemon(o)
 test_transfer("basic ipmisol", "This is a test!",
               ("connection: &con",
                "  accepter: tcp,3023",
-               "  connector: ipmisol,lan -U ipmiusr -P test -p 9001 localhost,9600"),
+               "  connector: ipmisol,lan -U ipmiusr -P test -p %d localhost,9600" % ipmisimdaemon.ipmisol_port),
               "tcp,localhost,3023",
               "serialdev,/dev/ttyPipeA0,9600N81")
 
@@ -26,7 +26,7 @@ gensio.waiter(o).wait_timeout(1, 1000)
 test_write_drain("basic tcp", "This is a write drain test!",
               ("connection: &con",
                "  accepter: tcp,3023",
-               "  connector: ipmisol,lan -U ipmiusr -P test -p 9001 localhost,9600"),
+               "  connector: ipmisol,lan -U ipmiusr -P test -p %d localhost,9600" % ipmisimdaemon.ipmisol_port),
                  "tcp,localhost,3023",
                  "serialdev,/dev/ttyPipeA0,9600N81,LOCAL",
                  switch_delay = 0.25)
